import { __decorate } from 'tslib';
import { ɵɵdefineInjectable, Injectable, EventEmitter, Input, Output, Component, ViewChild, ɵɵinject, ElementRef, HostListener, NgModule } from '@angular/core';
import { percent, unuseAllThemes, useTheme, create, color, InterfaceColorSet, Scrollbar, ease, ColorSet } from '@amcharts/amcharts4/core';
import { PieChart, PieSeries, Legend, XYChart, CategoryAxis, ValueAxis, ColumnSeries, LabelBullet, HeatLegend, TreeMap, DateAxis, LineSeries, CircleBullet, XYCursor, GaugeChart, ClockHand } from '@amcharts/amcharts4/charts';
import am4themes_animated from '@amcharts/amcharts4/themes/animated';
import am4themes_dataviz from '@amcharts/amcharts4/themes/dataviz';
import am4themes_material from '@amcharts/amcharts4/themes/material';
import am4themes_kelly from '@amcharts/amcharts4/themes/kelly';
import am4themes_frozen from '@amcharts/amcharts4/themes/frozen';
import am4themes_moonrisekingdom from '@amcharts/amcharts4/themes/moonrisekingdom';
import am4themes_spiritedaway from '@amcharts/amcharts4/themes/spiritedaway';
import { MatPaginator, MatPaginatorModule } from '@angular/material/paginator';
import { MatSort, MatSortModule } from '@angular/material/sort';
import { MatTableDataSource, MatTableModule } from '@angular/material/table';
import { GoogleMap, GoogleMapsModule } from '@angular/google-maps';
import am4lang_es_ES from '@amcharts/amcharts4/lang/es_ES';
import { HttpHeaders, HttpParams, HttpClient } from '@angular/common/http';
import { throwError } from 'rxjs';
import { map, catchError } from 'rxjs/operators';
import { CommonModule } from '@angular/common';
import { MatFormFieldModule } from '@angular/material/form-field';
import { MatInputModule } from '@angular/material/input';
import { MatIconModule } from '@angular/material/icon';
import { MatButtonModule } from '@angular/material/button';
import { MatBadgeModule } from '@angular/material/badge';
import { MatMenuModule } from '@angular/material/menu';
import { MatChipsModule } from '@angular/material/chips';

let GeneradorIdService = class GeneradorIdService {
    constructor() {
        this.id = 1;
    }
    obtenerId(prefijo = '') {
        this.id++;
        return prefijo + this.id;
    }
};
GeneradorIdService.ɵprov = ɵɵdefineInjectable({ factory: function GeneradorIdService_Factory() { return new GeneradorIdService(); }, token: GeneradorIdService, providedIn: "root" });
GeneradorIdService = __decorate([
    Injectable({
        providedIn: 'root',
    })
], GeneradorIdService);

let GraficoPastelComponent = class GraficoPastelComponent {
    constructor(generadorIdService) {
        this.seleccion = new EventEmitter();
        this.idGrafico = generadorIdService.obtenerId('gps_id_');
    }
    actualizarData() {
        this.chart.data = this.datos;
    }
    actualizarConfiguracion() {
        this.pieSeries.dataFields.value = this.config.campoValor;
        this.pieSeries.dataFields.category = this.config.campoCategoria;
        // this.pieSeries.labels.template.disabled = !this.config.mostrarEtiquetas;
        // this.pieSeries.ticks.template.disabled = !this.config.mostrarEtiquetas;
        this.chart.innerRadius = percent(this.config.porcentajeRadioInterno);
    }
    ngOnChanges(changes) {
        if (this.chart) {
            if (changes.datos) {
                this.actualizarData();
            }
            if (changes.config) {
                this.actualizarConfiguracion();
            }
        }
    }
    ngOnInit() { }
    ngAfterViewInit() {
        unuseAllThemes();
        switch (this.config.tipoVisual) {
            case 1:
                useTheme(am4themes_dataviz);
                break;
            case 2:
                useTheme(am4themes_material);
                break;
            case 3:
                useTheme(am4themes_kelly);
                break;
            case 4:
                useTheme(am4themes_frozen);
                break;
            case 5:
                useTheme(am4themes_moonrisekingdom);
                break;
            case 6:
                useTheme(am4themes_spiritedaway);
                break;
        }
        useTheme(am4themes_animated);
        this.chart = create(this.idGrafico, PieChart);
        // Add and configure Series
        this.pieSeries = this.chart.series.push(new PieSeries());
        this.pieSeries.slices.template.stroke = color('#fff');
        this.pieSeries.slices.template.strokeOpacity = 1;
        // This creates initial animation
        this.pieSeries.hiddenState.properties.opacity = 1;
        this.pieSeries.hiddenState.properties.endAngle = -90;
        this.pieSeries.hiddenState.properties.startAngle = -90;
        this.pieSeries.labels.template.maxWidth = 100;
        this.pieSeries.labels.template.wrap = true;
        this.pieSeries.labels.template.fontSize = 11;
        this.pieSeries.alignLabels = false;
        // Evento click
        this.pieSeries.slices.template.events.on('hit', (event) => {
            this.seleccion.emit(event.target.dataItem.dataContext);
        });
        this.chart.legend = new Legend();
        this.chart.legend.markers.template.width = 8;
        this.chart.legend.markers.template.height = 8;
        this.chart.legend.markers.template.dy = 0;
        this.chart.legend.itemContainers.template.fontSize = '12px';
        this.chart.legend.itemContainers.template.paddingTop = 2;
        this.chart.legend.itemContainers.template.paddingBottom = 2;
        this.chart.legend.paddingTop = 20;
        this.chart.padding(20, 10, 20, 10);
        this.actualizarConfiguracion();
        this.actualizarData();
    }
    ngOnDestroy() {
        this.chart.dispose();
    }
};
GraficoPastelComponent.ctorParameters = () => [
    { type: GeneradorIdService }
];
__decorate([
    Input()
], GraficoPastelComponent.prototype, "config", void 0);
__decorate([
    Input()
], GraficoPastelComponent.prototype, "datos", void 0);
__decorate([
    Output()
], GraficoPastelComponent.prototype, "seleccion", void 0);
GraficoPastelComponent = __decorate([
    Component({
        selector: 'lib-grafico-pastel',
        template: "<div id=\"{{idGrafico}}\" style=\"width: 100%; height: 100%\"></div>\n",
        styles: [":host{display:block}"]
    })
], GraficoPastelComponent);

let GraficoTablaComponent = class GraficoTablaComponent {
    constructor() {
        this.seleccion = new EventEmitter();
    }
    ngOnChanges(changes) {
        this.dataSource = new MatTableDataSource(this.datos);
        this.displayedColumns = this.config.columnas.map((a) => a.campo);
        this.dataSource.paginator = this.paginator;
        this.dataSource.sort = this.sort;
    }
    ngOnInit() { }
    applyFilter(event) {
        const filterValue = event.target.value;
        this.dataSource.filter = filterValue.trim().toLowerCase();
        if (this.dataSource.paginator) {
            this.dataSource.paginator.firstPage();
        }
    }
    clickFila(fila) {
        this.seleccion.emit(fila);
    }
};
__decorate([
    ViewChild(MatPaginator, { static: true })
], GraficoTablaComponent.prototype, "paginator", void 0);
__decorate([
    ViewChild(MatSort, { static: true })
], GraficoTablaComponent.prototype, "sort", void 0);
__decorate([
    Input()
], GraficoTablaComponent.prototype, "config", void 0);
__decorate([
    Input()
], GraficoTablaComponent.prototype, "datos", void 0);
__decorate([
    Output()
], GraficoTablaComponent.prototype, "seleccion", void 0);
GraficoTablaComponent = __decorate([
    Component({
        selector: 'lib-grafico-tabla',
        template: "<div class=\"example-container mat-elevation-z8\">\n    <mat-form-field class=\"filtro\"  *ngIf=\"config.conFiltro\">\n        <mat-label>Filtrar</mat-label>\n        <input matInput (keyup)=\"applyFilter($event)\" #input autocomplete=\"off\">\n        <mat-icon matSuffix>search</mat-icon>\n    </mat-form-field>\n\n    <mat-table #table [dataSource]=\"dataSource\" matSort [ngStyle]=\"{'min-width': displayedColumns.length*120+'px'}\">\n\n        <ng-container matColumnDef=\"{{column}}\" *ngFor=\"let column of displayedColumns; let i=index\">\n            <mat-header-cell *matHeaderCellDef mat-sort-header>{{config.columnas[i].titulo}}</mat-header-cell>\n            <mat-cell *matCellDef=\"let element\">\n                <span *ngIf=\"config.columnas[i].campoEnlace\">\n                    <mat-chip style=\"background: none;\" *ngFor=\"let enlace of element[config.columnas[i].campoEnlace]\">\n                        <a mat-icon-button [href]=\"enlace\" target=\"_blank\">\n                            <mat-icon>link</mat-icon>\n                        </a>\n                    </mat-chip>\n                </span>\n                <mat-chip-list *ngIf=\"config.columnas[i].colorPildora\">\n                    <mat-chip [ngStyle]=\"{'background-color': config.columnas[i].colorPildora, 'color': config.columnas[i].colorTextoPildora?config.columnas[i].colorTextoPildora:'#333'}\">{{element[column]}}</mat-chip>\n                </mat-chip-list>\n                <span *ngIf=\"!config.columnas[i].colorPildora\">{{element[column]}}</span>\n            </mat-cell>\n        </ng-container>\n\n\n        <mat-header-row *matHeaderRowDef=\"displayedColumns; sticky: true\"></mat-header-row>\n        <mat-row *matRowDef=\"let row; columns: displayedColumns;\" (click)=\"clickFila(row)\"></mat-row>\n\n        <!-- Angular 10\n        <mat-row *matNoDataRow>\n            <mat-cell colspan=\"4\">No data matching the filter \"{{input.value}}\"</mat-cell>\n        </mat-row> -->\n    </mat-table>\n    <mat-paginator *ngIf=\"config.conPaginacion\" [pageSizeOptions]=\"[5, 10, 25, 100]\"></mat-paginator>\n</div>",
        styles: [":host{height:100%;width:100%;display:block}.example-container{height:100%;width:100%;max-width:100%;overflow:auto}.mat-form-field.filtro{font-size:14px;margin:8px 0 0;width:100%;max-width:400px}::ng-deep .filtro .mat-form-field-wrapper{margin:0 20px -1.25em}.mat-row{cursor:pointer}.mat-row:hover{background-color:#e3e3e3}"]
    })
], GraficoTablaComponent);

let GraficoMapaComponent = class GraficoMapaComponent {
    constructor() {
        this.seleccion = new EventEmitter();
    }
    ngOnChanges(changes) {
        this.centrarMapa();
    }
    ngOnInit() { }
    clickMarker(data) {
        this.seleccion.emit(data);
    }
    centrarMapa() {
        if (this.datos.length) {
            if (this.datos.length === 1) {
                for (const dato of this.datos) {
                    this.map.panTo({
                        lat: dato[this.config.campoLatitud],
                        lng: dato[this.config.campoLongitud],
                    });
                }
            }
            else {
                const bounds = new google.maps.LatLngBounds();
                for (const dato of this.datos) {
                    bounds.extend({
                        lat: dato[this.config.campoLatitud],
                        lng: dato[this.config.campoLongitud],
                    });
                }
                this.map.fitBounds(bounds);
            }
        }
    }
};
__decorate([
    Input()
], GraficoMapaComponent.prototype, "config", void 0);
__decorate([
    Input()
], GraficoMapaComponent.prototype, "datos", void 0);
__decorate([
    Output()
], GraficoMapaComponent.prototype, "seleccion", void 0);
__decorate([
    ViewChild(GoogleMap)
], GraficoMapaComponent.prototype, "map", void 0);
GraficoMapaComponent = __decorate([
    Component({
        selector: 'lib-grafico-mapa',
        template: "<google-map width=\"100%\" height=\"100%\" [options]=\"{mapTypeControl:false, fullscreenControl:false, streetViewControl:false}\" [zoom]=\"4\">\n    <map-marker #marker *ngFor=\"let m of datos\" [position]=\"{lat:m[config.campoLatitud], lng:m[config.campoLongitud]}\" [options]=\"{draggable:false, icon:config.icono}\"\n        [title]=\"m.titulo\" (mapClick)=\"clickMarker(m)\">\n    </map-marker>\n</google-map>",
        styles: [":host{display:block}"]
    })
], GraficoMapaComponent);

let GraficoBarrasComponent = class GraficoBarrasComponent {
    constructor(generadorIdService) {
        this.seleccion = new EventEmitter();
        this.idGrafico = generadorIdService.obtenerId('gbr_id_');
    }
    actualizarData() {
        this.chart.data = this.datos;
    }
    actualizarConfiguracion() {
        this.categoryAxis.dataFields.category = this.config.campoCategoria;
        this.series.dataFields.valueY = this.config.campoValor;
        this.series.dataFields.categoryX = this.config.campoCategoria;
    }
    ngOnChanges(changes) {
        if (this.chart) {
            if (changes.datos) {
                this.actualizarData();
            }
            if (changes.config) {
                this.actualizarConfiguracion();
            }
        }
    }
    ngOnInit() { }
    ngAfterViewInit() {
        unuseAllThemes();
        switch (this.config.tipoVisual) {
            case 1:
                useTheme(am4themes_dataviz);
                break;
            case 2:
                useTheme(am4themes_material);
                break;
            case 3:
                useTheme(am4themes_kelly);
                break;
            case 4:
                useTheme(am4themes_frozen);
                break;
            case 5:
                useTheme(am4themes_moonrisekingdom);
                break;
            case 6:
                useTheme(am4themes_spiritedaway);
                break;
        }
        useTheme(am4themes_animated);
        this.chart = create(this.idGrafico, XYChart);
        this.chart.padding(30, 10, 10, 10);
        // Create axes
        this.categoryAxis = this.chart.xAxes.push(new CategoryAxis());
        this.categoryAxis.fontSize = 11;
        this.categoryAxis.renderer.grid.template.location = 0;
        this.categoryAxis.renderer.minGridDistance = 30;
        this.categoryAxis.renderer.grid.template.disabled = true;
        this.categoryAxis.renderer.labels.template.horizontalCenter = 'right';
        this.categoryAxis.renderer.labels.template.verticalCenter = 'middle';
        this.categoryAxis.renderer.labels.template.rotation = 270;
        const valueAxis = this.chart.yAxes.push(new ValueAxis());
        // Create series
        this.series = this.chart.series.push(new ColumnSeries());
        this.series.columns.template.tooltipText = '{categoryX}: {valueY.value}';
        this.series.columns.template.strokeOpacity = 0;
        this.series.columns.template.adapter.add('fill', (fill, target) => {
            return this.chart.colors.getIndex(target.dataItem.index);
        });
        const labelBullet = this.series.bullets.push(new LabelBullet());
        labelBullet.label.text = '{valueY}';
        labelBullet.label.verticalCenter = 'bottom';
        labelBullet.label.dy = -4;
        labelBullet.label.hideOversized = true;
        this.categoryAxis.sortBySeries = this.series;
        // Evento click
        this.series.columns.template.events.on('hit', (event) => {
            this.seleccion.emit(event.target.dataItem.dataContext);
        });
        this.actualizarConfiguracion();
        this.actualizarData();
    }
    ngOnDestroy() {
        this.chart.dispose();
    }
};
GraficoBarrasComponent.ctorParameters = () => [
    { type: GeneradorIdService }
];
__decorate([
    Input()
], GraficoBarrasComponent.prototype, "config", void 0);
__decorate([
    Input()
], GraficoBarrasComponent.prototype, "datos", void 0);
__decorate([
    Output()
], GraficoBarrasComponent.prototype, "seleccion", void 0);
GraficoBarrasComponent = __decorate([
    Component({
        selector: 'lib-grafico-barras',
        template: "<div id=\"{{idGrafico}}\" style=\"width: 100%; height: 100%\"></div>",
        styles: [":host{display:block}"]
    })
], GraficoBarrasComponent);

let GraficoIndicadorComponent = class GraficoIndicadorComponent {
    constructor() {
        this.seleccion = new EventEmitter();
    }
    ngOnChanges() {
        this.alertaActiva =
            (this.config.alertaLimiteInferior != null &&
                this.config.alertaLimiteInferior >
                    this.datos[this.config.campoValor]) ||
                (this.config.alertaLimiteSuperior != null &&
                    this.config.alertaLimiteSuperior < this.datos[this.config.campoValor]);
    }
    ngOnInit() { }
    onClick() {
        if ((this.config.alertaLimiteInferior != null &&
            this.config.alertaLimiteInferior >
                this.datos[this.config.campoValor]) ||
            (this.config.alertaLimiteSuperior != null &&
                this.config.alertaLimiteSuperior < this.datos[this.config.campoValor])) {
            this.seleccion.emit(this.datos);
        }
    }
};
__decorate([
    Input()
], GraficoIndicadorComponent.prototype, "config", void 0);
__decorate([
    Input()
], GraficoIndicadorComponent.prototype, "datos", void 0);
__decorate([
    Output()
], GraficoIndicadorComponent.prototype, "seleccion", void 0);
GraficoIndicadorComponent = __decorate([
    Component({
        selector: 'lib-grafico-indicador',
        template: "<div [style]=\"'width: 100%; height: 100%; background:'+config.color\" (click)=\"onClick()\"\n    [ngClass]=\"{'alertaActiva': alertaActiva}\">\n    <div [ngClass]=\"{'texto_blanco': config.textoBlanco, 'tamano_grande':config.esGrande}\">\n        <mat-icon aria-hidden=\"false\">{{config.icono}}</mat-icon>\n        <p>{{datos[config.campoValor]}}<span *ngIf=\"config.unidad\"> {{config.unidad}}</span></p>\n        <p>{{config.descripcion}}</p>\n    </div>\n</div>",
        styles: [":host>div{display:flex;justify-content:center;align-items:center}:host>div>div{width:100%;max-width:300px;padding:12px}:host>div>div .mat-icon{font-size:34px;float:left;margin:0;height:auto;width:auto}:host>div>div p:first-of-type{text-align:right;margin:0 0 0 36px;font-size:28px;line-height:28px;white-space:nowrap}:host>div>div p:first-of-type>span{font-size:14px;vertical-align:middle}:host>div>div p:last-of-type{text-align:right;margin:-4px 0 0;font-size:12px;white-space:nowrap}:host>div .tamano_grande p:first-of-type{font-size:38px;line-height:38px}:host>div .tamano_grande p:last-of-type{margin:-4px 0 0}:host>div .texto_blanco{color:#fff}@-webkit-keyframes animation-parpadear{0%,80%{opacity:1}25%{opacity:.25}50%{opacity:.5}}@keyframes animation-parpadear{0%,80%{opacity:1}25%{opacity:.25}50%{opacity:.5}}.alertaActiva{-webkit-animation:2s linear infinite animation-parpadear;animation:2s linear infinite animation-parpadear;cursor:pointer}.alertaActiva:hover{-webkit-animation:none;animation:none}"]
    })
], GraficoIndicadorComponent);

let GraficoHeatmapComponent = class GraficoHeatmapComponent {
    constructor(generadorIdService) {
        this.seleccion = new EventEmitter();
        this.idGrafico = generadorIdService.obtenerId('gp_id_');
    }
    actualizarData() {
        this.chart.data = this.datos;
    }
    actualizarConfiguracion() {
        this.xAxis.dataFields.category = this.config.campoX;
        this.yAxis.dataFields.category = this.config.campoY;
        this.series.dataFields.categoryX = this.config.campoX;
        this.series.dataFields.categoryY = this.config.campoY;
        this.series.dataFields.value = this.config.campoValor;
    }
    ngOnChanges(changes) {
        if (this.chart) {
            if (changes.datos) {
                this.actualizarData();
            }
            if (changes.config) {
                this.actualizarConfiguracion();
            }
        }
    }
    ngOnInit() { }
    ngAfterViewInit() {
        unuseAllThemes();
        switch (this.config.tipoVisual) {
            case 1:
                useTheme(am4themes_dataviz);
                break;
            case 2:
                useTheme(am4themes_material);
                break;
            case 3:
                useTheme(am4themes_kelly);
                break;
            case 4:
                useTheme(am4themes_frozen);
                break;
            case 5:
                useTheme(am4themes_moonrisekingdom);
                break;
            case 6:
                useTheme(am4themes_spiritedaway);
                break;
        }
        useTheme(am4themes_animated);
        this.chart = create(this.idGrafico, XYChart);
        this.chart.maskBullets = false;
        this.xAxis = this.chart.xAxes.push(new CategoryAxis());
        this.yAxis = this.chart.yAxes.push(new CategoryAxis());
        this.xAxis.renderer.grid.template.disabled = true;
        this.xAxis.renderer.minGridDistance = 40;
        this.yAxis.renderer.grid.template.disabled = true;
        this.yAxis.renderer.inversed = true;
        this.yAxis.renderer.minGridDistance = 30;
        this.series = this.chart.series.push(new ColumnSeries());
        this.series.sequencedInterpolation = true;
        this.series.defaultState.transitionDuration = 3000;
        const bgColor = new InterfaceColorSet().getFor('background');
        const columnTemplate = this.series.columns.template;
        columnTemplate.strokeWidth = 1;
        columnTemplate.strokeOpacity = 0.2;
        columnTemplate.stroke = bgColor;
        columnTemplate.tooltipText = '{value}';
        columnTemplate.width = percent(100);
        columnTemplate.height = percent(100);
        this.series.heatRules.push({
            target: columnTemplate,
            property: 'fill',
            min: color(bgColor),
            max: this.chart.colors.getIndex(0),
        });
        // Evento click
        this.series.columns.template.events.on('hit', (event) => {
            this.seleccion.emit(event.target.dataItem.dataContext);
        });
        // heat legend
        this.heatLegend = this.chart.bottomAxesContainer.createChild(HeatLegend);
        this.heatLegend.width = percent(100);
        this.heatLegend.series = this.series;
        this.heatLegend.valueAxis.renderer.labels.template.fontSize = 9;
        this.heatLegend.valueAxis.renderer.minGridDistance = 30;
        // heat legend behavior
        this.series.columns.template.events.on('over', (event) => {
            this.handleHover(event.target);
        });
        this.series.columns.template.events.on('hit', (event) => {
            this.handleHover(event.target);
        });
        this.series.columns.template.events.on('out', (event) => {
            this.heatLegend.valueAxis.hideTooltip();
        });
        this.actualizarConfiguracion();
        this.actualizarData();
    }
    handleHover(column) {
        if (!isNaN(column.dataItem.value)) {
            this.heatLegend.valueAxis.showTooltipAt(column.dataItem.value);
        }
        else {
            this.heatLegend.valueAxis.hideTooltip();
        }
    }
    ngOnDestroy() {
        this.chart.dispose();
    }
};
GraficoHeatmapComponent.ctorParameters = () => [
    { type: GeneradorIdService }
];
__decorate([
    Input()
], GraficoHeatmapComponent.prototype, "config", void 0);
__decorate([
    Input()
], GraficoHeatmapComponent.prototype, "datos", void 0);
__decorate([
    Output()
], GraficoHeatmapComponent.prototype, "seleccion", void 0);
GraficoHeatmapComponent = __decorate([
    Component({
        selector: 'lib-grafico-heatmap',
        template: "<div id=\"{{idGrafico}}\" style=\"width: 100%; height: 100%\"></div>",
        styles: [":host{display:block}"]
    })
], GraficoHeatmapComponent);

let GraficoTreemapComponent = class GraficoTreemapComponent {
    constructor(generadorIdService) {
        this.seleccion = new EventEmitter();
        this.idGrafico = generadorIdService.obtenerId('gtm_id_');
    }
    actualizarData() {
        this.chart.data = this.datos;
    }
    actualizarConfiguracion() {
        this.chart.dataFields.value = this.config.campoValor;
        this.chart.dataFields.name = this.config.campoCategoria;
    }
    ngOnChanges(changes) {
        if (this.chart) {
            if (changes.datos) {
                this.actualizarData();
            }
            if (changes.config) {
                this.actualizarConfiguracion();
            }
        }
    }
    ngOnInit() { }
    ngAfterViewInit() {
        unuseAllThemes();
        switch (this.config.tipoVisual) {
            case 1:
                useTheme(am4themes_dataviz);
                break;
            case 2:
                useTheme(am4themes_material);
                break;
            case 3:
                useTheme(am4themes_kelly);
                break;
            case 4:
                useTheme(am4themes_frozen);
                break;
            case 5:
                useTheme(am4themes_moonrisekingdom);
                break;
            case 6:
                useTheme(am4themes_spiritedaway);
                break;
        }
        useTheme(am4themes_animated);
        this.chart = create(this.idGrafico, TreeMap);
        this.chart.hiddenState.properties.opacity = 0; // this makes initial fade in effect
        this.chart.colors.step = 2;
        this.chart.zoomable = false;
        const bgColor = new InterfaceColorSet().getFor('background');
        // level 0 series template
        const level0SeriesTemplate = this.chart.seriesTemplates.create('0');
        const level0ColumnTemplate = level0SeriesTemplate.columns.template;
        const bullet1 = level0SeriesTemplate.bullets.push(new LabelBullet());
        bullet1.locationY = 0.5;
        bullet1.locationX = 0.5;
        bullet1.label.text = '{name}';
        bullet1.label.fill = color('#ffffff');
        this.chart.maxLevels = 2;
        level0SeriesTemplate.columns.template.events.on('hit', (event) => {
            this.seleccion.emit(event.target.dataItem.dataContext
                .dataContext);
        });
        this.actualizarConfiguracion();
        this.actualizarData();
    }
    ngOnDestroy() {
        this.chart.dispose();
    }
};
GraficoTreemapComponent.ctorParameters = () => [
    { type: GeneradorIdService }
];
__decorate([
    Input()
], GraficoTreemapComponent.prototype, "config", void 0);
__decorate([
    Input()
], GraficoTreemapComponent.prototype, "datos", void 0);
__decorate([
    Output()
], GraficoTreemapComponent.prototype, "seleccion", void 0);
GraficoTreemapComponent = __decorate([
    Component({
        selector: 'lib-grafico-treemap',
        template: "<div id=\"{{idGrafico}}\" style=\"width: 100%; height: 100%\"></div>",
        styles: [":host{display:block}"]
    })
], GraficoTreemapComponent);

let GraficoLineaComponent = class GraficoLineaComponent {
    constructor(generadorIdService) {
        this.seleccion = new EventEmitter();
        this.idGrafico = generadorIdService.obtenerId('gln_id_');
    }
    actualizarData() {
        this.chart.data = this.datos;
    }
    actualizarConfiguracion() {
        this.chart.dateFormatter.inputDateFormat = this.config.formatoDatosFecha;
        this.valueAxis.title.text = this.config.etiquetaValor;
        this.series.dataFields.valueY = this.config.campoValor;
        this.series.dataFields.dateX = this.config.campoFecha;
    }
    ngOnChanges(changes) {
        if (this.chart) {
            if (changes.datos) {
                this.actualizarData();
            }
            if (changes.config) {
                this.actualizarConfiguracion();
            }
        }
    }
    ngOnInit() { }
    ngAfterViewInit() {
        unuseAllThemes();
        switch (this.config.tipoVisual) {
            case 1:
                useTheme(am4themes_dataviz);
                break;
            case 2:
                useTheme(am4themes_material);
                break;
            case 3:
                useTheme(am4themes_kelly);
                break;
            case 4:
                useTheme(am4themes_frozen);
                break;
            case 5:
                useTheme(am4themes_moonrisekingdom);
                break;
            case 6:
                useTheme(am4themes_spiritedaway);
                break;
        }
        useTheme(am4themes_animated);
        this.chart = create(this.idGrafico, XYChart);
        this.chart.language.locale = am4lang_es_ES;
        // Create axes
        const dateAxis = this.chart.xAxes.push(new DateAxis());
        this.valueAxis = this.chart.yAxes.push(new ValueAxis());
        // Create series
        this.series = this.chart.series.push(new LineSeries());
        this.series.strokeWidth = 2;
        this.series.fillOpacity = 0.5;
        // Make bullets grow on hover
        const bullet = this.series.bullets.push(new CircleBullet());
        bullet.circle.strokeWidth = 1.5;
        bullet.circle.radius = 3;
        // Make a panning cursor
        this.chart.cursor = new XYCursor();
        // this.chart.cursor.behavior = 'panXY';
        this.chart.cursor.xAxis = dateAxis;
        this.chart.cursor.snapToSeries = this.series;
        this.chart.scrollbarX = new Scrollbar();
        this.chart.scrollbarX.parent = this.chart.bottomAxesContainer;
        this.series.events.on('hit', (event) => {
            console.log(event);
        });
        this.actualizarConfiguracion();
        this.actualizarData();
    }
    ngOnDestroy() {
        this.chart.dispose();
    }
};
GraficoLineaComponent.ctorParameters = () => [
    { type: GeneradorIdService }
];
__decorate([
    Input()
], GraficoLineaComponent.prototype, "config", void 0);
__decorate([
    Input()
], GraficoLineaComponent.prototype, "datos", void 0);
__decorate([
    Output()
], GraficoLineaComponent.prototype, "seleccion", void 0);
GraficoLineaComponent = __decorate([
    Component({
        selector: 'lib-grafico-linea',
        template: "<div id=\"{{idGrafico}}\" style=\"width: 100%; height: 100%\"></div>",
        styles: [":host{display:block}"]
    })
], GraficoLineaComponent);

let GraficoVelocimetroComponent = class GraficoVelocimetroComponent {
    constructor(generadorIdService) {
        this.seleccion = new EventEmitter();
        this.idGrafico = generadorIdService.obtenerId('gvl_id_');
    }
    actualizarData() {
        this.hand.showValue(this.datos[this.config.campoValor], 1000, ease.cubicOut);
    }
    actualizarConfiguracion() {
        const colorSet = new ColorSet();
        this.axis.min = this.config.valorMinimo;
        this.axis.max = this.config.valorMaximo;
        // rango 0 - Color
        this.range0.value = this.config.valorMinimo;
        this.range0.endValue =
            this.config.valorMinimo +
                Math.round((this.config.valorMaximo - this.config.valorMinimo) / 2);
        this.range0.axisFill.fill = this.config.color1
            ? color(this.config.color1)
            : colorSet.getIndex(0);
        // rango 1 - Color
        this.range1.value =
            this.config.valorMinimo +
                Math.round((this.config.valorMaximo - this.config.valorMinimo) / 2);
        this.range1.endValue =
            this.config.valorMinimo +
                Math.round((this.config.valorMaximo - this.config.valorMinimo) / 2) +
                Math.round((this.config.valorMaximo - this.config.valorMinimo) / 4);
        this.range1.axisFill.fill = this.config.color2
            ? color(this.config.color2)
            : colorSet.getIndex(2);
        // rango 2 - Color
        this.range2.value =
            this.config.valorMinimo +
                Math.round((this.config.valorMaximo - this.config.valorMinimo) / 2) +
                Math.round((this.config.valorMaximo - this.config.valorMinimo) / 4);
        this.range2.endValue = this.config.valorMaximo;
        this.range2.axisFill.fill = this.config.color3
            ? color(this.config.color3)
            : colorSet.getIndex(4);
    }
    ngOnChanges(changes) {
        if (this.chart) {
            if (changes.datos) {
                this.actualizarData();
            }
            if (changes.config) {
                this.actualizarConfiguracion();
            }
        }
    }
    ngOnInit() { }
    ngAfterViewInit() {
        unuseAllThemes();
        switch (this.config.tipoVisual) {
            case 1:
                useTheme(am4themes_dataviz);
                break;
            case 2:
                useTheme(am4themes_material);
                break;
            case 3:
                useTheme(am4themes_kelly);
                break;
            case 4:
                useTheme(am4themes_frozen);
                break;
            case 5:
                useTheme(am4themes_moonrisekingdom);
                break;
            case 6:
                useTheme(am4themes_spiritedaway);
                break;
        }
        useTheme(am4themes_animated);
        this.chart = create(this.idGrafico, GaugeChart);
        this.chart.hiddenState.properties.opacity = 0; // this makes initial fade in effect
        this.chart.innerRadius = -25;
        this.axis = this.chart.xAxes.push(new ValueAxis());
        this.axis.strictMinMax = true;
        this.axis.renderer.grid.template.stroke = new InterfaceColorSet().getFor('background');
        this.axis.renderer.grid.template.strokeOpacity = 0.3;
        this.range0 = this.axis.axisRanges.create();
        this.range0.axisFill.fillOpacity = 1;
        this.range0.axisFill.zIndex = -1;
        this.range1 = this.axis.axisRanges.create();
        this.range1.axisFill.fillOpacity = 1;
        this.range1.axisFill.zIndex = -1;
        this.range2 = this.axis.axisRanges.create();
        this.range2.axisFill.fillOpacity = 1;
        this.range2.axisFill.zIndex = -1;
        this.hand = this.chart.hands.push(new ClockHand());
        this.actualizarConfiguracion();
        this.actualizarData();
    }
    ngOnDestroy() {
        this.chart.dispose();
    }
};
GraficoVelocimetroComponent.ctorParameters = () => [
    { type: GeneradorIdService }
];
__decorate([
    Input()
], GraficoVelocimetroComponent.prototype, "config", void 0);
__decorate([
    Input()
], GraficoVelocimetroComponent.prototype, "datos", void 0);
__decorate([
    Output()
], GraficoVelocimetroComponent.prototype, "seleccion", void 0);
GraficoVelocimetroComponent = __decorate([
    Component({
        selector: 'lib-grafico-velocimetro',
        template: "<div id=\"{{idGrafico}}\" style=\"width: 100%; height: 100%\"></div>\n",
        styles: [":host{display:block}"]
    })
], GraficoVelocimetroComponent);

let ApiService = class ApiService {
    constructor(http) {
        this.http = http;
    }
    post(url, parametros, jwt) {
        const headers = new HttpHeaders({
            Authorization: `Bearer ${jwt}`,
        });
        let params = new HttpParams();
        // tslint:disable-next-line: forin
        for (const key in parametros) {
            params = params.append(key, parametros[key]);
        }
        return this.http
            .post(url, {
            headers,
            params,
        })
            .pipe(map((resp) => {
            return resp;
        }), catchError((error) => {
            return throwError(error.error);
        }));
    }
    get(url, parametros, jwt) {
        const headers = new HttpHeaders({
            Authorization: `Bearer ${jwt}`,
        });
        let params = new HttpParams();
        // tslint:disable-next-line: forin
        for (const key in parametros) {
            params = params.append(key, parametros[key]);
        }
        return this.http
            .get(url, {
            headers,
            params,
        })
            .pipe(map((resp) => {
            return resp;
        }), catchError((error) => {
            return throwError(error.error);
        }));
    }
};
ApiService.ctorParameters = () => [
    { type: HttpClient }
];
ApiService.ɵprov = ɵɵdefineInjectable({ factory: function ApiService_Factory() { return new ApiService(ɵɵinject(HttpClient)); }, token: ApiService, providedIn: "root" });
ApiService = __decorate([
    Injectable({
        providedIn: 'root',
    })
], ApiService);

let DashboardComponent = class DashboardComponent {
    constructor(el, apiService) {
        this.el = el;
        this.apiService = apiService;
        this.divisionTamano = 10;
        this.idxPanelPantallaCompleta = null;
        this.datos = [];
    }
    ngOnInit() {
        this.calcularVariablesTamano();
        this.recargarDatos();
    }
    onResize() {
        this.calcularVariablesTamano();
    }
    onCambioFiltro(i, data) {
        let encontrado = false;
        this.config.filtros.forEach((filtro, idx) => {
            if (filtro.llave === i) {
                encontrado = true;
                if (data) {
                    filtro.filtros = data;
                }
                else {
                    this.config.filtros.splice(idx, 1);
                }
            }
        });
        if (!encontrado) {
            this.config.filtros.push({ llave: i, filtros: data });
        }
        this.recargarDatos();
    }
    onPantallaCompleta(idxPanel) {
        if (this.idxPanelPantallaCompleta === idxPanel) {
            this.idxPanelPantallaCompleta = null;
        }
        else {
            this.idxPanelPantallaCompleta = idxPanel;
        }
        console.log(this.idxPanelPantallaCompleta);
    }
    calcularVariablesTamano() {
        this.anchoElemento = this.el.nativeElement.offsetWidth;
        let sel = this.config.pantallas[0];
        for (const pantalla of this.config.pantallas) {
            if (pantalla.tamanoMinimoX < this.anchoElemento &&
                pantalla.tamanoMinimoX > sel.tamanoMinimoX) {
                sel = pantalla;
            }
        }
        this.configuracionPantalla = sel;
        this.altoGrilla =
            (1 / this.configuracionPantalla.relacionXY) *
                ((this.anchoElemento - this.divisionTamano) /
                    this.configuracionPantalla.cantidadX -
                    this.divisionTamano);
    }
    obtenerConfigPanelPantalla(pantallas) {
        let sel = pantallas[0];
        for (const pantalla of pantallas) {
            if (pantalla.tamanoMinimoX < this.anchoElemento &&
                pantalla.tamanoMinimoX > sel.tamanoMinimoX) {
                sel = pantalla;
            }
        }
        return sel;
    }
    obtenerFiltrosUnificados(filtros) {
        const resp = {};
        filtros.forEach((filtro) => {
            // tslint:disable-next-line: forin
            for (const key in filtro.filtros) {
                resp[key] = filtro.filtros[key];
            }
        });
        return resp;
    }
    recargarDatos() {
        if (this.config.servicioDatos && this.config.servicioDatos.url) {
            this.config.paneles.forEach((panel) => {
                if (!panel.servicioDatos || !panel.servicioDatos.url) {
                    panel.estaCargando = true;
                }
            });
            let filtros = {};
            if (this.config.servicioDatos.fncProcesarFiltros) {
                filtros = this.config.servicioDatos.fncProcesarFiltros(this.config.filtros);
            }
            else {
                filtros = this.obtenerFiltrosUnificados(this.config.filtros);
            }
            let consumirServicio = true;
            if (this.config.servicioDatos.fncPreconsumo) {
                const datos = this.config.servicioDatos.fncPreconsumo(this.datos, this.config.filtros);
                if (datos !== null) {
                    consumirServicio = false;
                    this.datos = datos;
                }
            }
            if (consumirServicio) {
                let peticion;
                if (this.config.servicioDatos.method === 'Post') {
                    peticion = this.apiService.post(this.config.servicioDatos.url, filtros, this.config.jwt);
                }
                else {
                    peticion = this.apiService.get(this.config.servicioDatos.url, filtros, this.config.jwt);
                }
                peticion.subscribe((datosServidor) => {
                    if (this.config.servicioDatos.fncPostconsumo) {
                        datosServidor = this.config.servicioDatos.fncPostconsumo(datosServidor, this.config.filtros);
                    }
                    this.datos = datosServidor;
                    this.config.paneles.forEach((panel) => {
                        if (!panel.servicioDatos || !panel.servicioDatos.url) {
                            panel.datos = datosServidor;
                            panel.estaCargando = false;
                        }
                    });
                });
            }
            else {
                if (this.config.servicioDatos.fncPostconsumo) {
                    this.datos = this.config.servicioDatos.fncPostconsumo(this.datos, this.config.filtros);
                }
                this.config.paneles.forEach((panel) => {
                    if (!panel.servicioDatos || !panel.servicioDatos.url) {
                        panel.datos = this.datos;
                        panel.estaCargando = false;
                    }
                });
            }
        }
    }
};
DashboardComponent.ctorParameters = () => [
    { type: ElementRef },
    { type: ApiService }
];
__decorate([
    Input()
], DashboardComponent.prototype, "config", void 0);
__decorate([
    HostListener('window:resize', [])
], DashboardComponent.prototype, "onResize", null);
DashboardComponent = __decorate([
    Component({
        selector: 'wm-dashboard',
        template: "<div\n    [style]=\"'grid-template-columns: repeat('+configuracionPantalla.cantidadX+', 1fr); grid-gap: '+divisionTamano+'px; padding: '+divisionTamano+'px; grid-auto-rows: minmax('+altoGrilla+'px, '+altoGrilla+'px)'\">\n    <wm-dashboard-panel *ngFor=\"let panel of config.paneles; let i = index\" class=\"mat-elevation-z2\"\n        [ngClass]=\"{'pantalla_completa':i==idxPanelPantallaCompleta}\"\n        [style]=\"'grid-column: '+obtenerConfigPanelPantalla(panel.pantallas).posicionX+' / span '+obtenerConfigPanelPantalla(panel.pantallas).tamanoX+'; grid-row: '+obtenerConfigPanelPantalla(panel.pantallas).posicionY+' / span '+obtenerConfigPanelPantalla(panel.pantallas).tamanoY\"\n        [config]=\"panel\" [datos]=\"panel.datos\" (filtro)=\"onCambioFiltro(i, $event)\"\n        (pantallaCompleta)=\"onPantallaCompleta(i)\">\n    </wm-dashboard-panel>\n</div>",
        styles: [":host{display:block;overflow:auto}:host>div{display:-ms-grid;display:grid}.pantalla_completa{position:fixed;top:0;bottom:0;right:0;left:0;z-index:1000}"]
    })
], DashboardComponent);

let DashboardPanelComponent = class DashboardPanelComponent {
    constructor() {
        this.filtro = new EventEmitter();
        this.pantallaCompleta = new EventEmitter();
        this.estaFiltrado = false;
    }
    ngOnInit() {
        this.datosGrafico = [];
    }
    ngOnChanges(changes) {
        if (this.datos &&
            this.config.servicioDatos &&
            this.config.servicioDatos.fncTransformacionDatos) {
            this.datosGrafico = this.config.servicioDatos.fncTransformacionDatos(this.datos);
        }
    }
    graficoSeleccion(data) {
        if (this.config.servicioDatos &&
            this.config.servicioDatos.fncTransformacionFiltros) {
            this.estaFiltrado = true;
            this.filtro.emit(this.config.servicioDatos.fncTransformacionFiltros(data));
        }
    }
    eliminarFiltro() {
        this.estaFiltrado = false;
        this.filtro.emit();
    }
    onPantallaCompleta() {
        this.pantallaCompleta.emit(this);
    }
};
__decorate([
    Input()
], DashboardPanelComponent.prototype, "config", void 0);
__decorate([
    Input()
], DashboardPanelComponent.prototype, "datos", void 0);
__decorate([
    Output()
], DashboardPanelComponent.prototype, "filtro", void 0);
__decorate([
    Output()
], DashboardPanelComponent.prototype, "pantallaCompleta", void 0);
DashboardPanelComponent = __decorate([
    Component({
        selector: 'wm-dashboard-panel',
        template: "<div class=\"titulo\" *ngIf=\"config.conTitulo\">\n    <div>{{config.titulo}}</div>\n    <button mat-icon-button *ngIf=\"estaFiltrado\" (click)=\"eliminarFiltro()\">\n        <mat-icon matBadge=\"!\" matBadgeColor=\"warn\" matBadgeSize=\"small\">filter_alt</mat-icon>\n    </button>\n    <button mat-icon-button *ngIf=\"config.permiteZoom\"(click)=\"onPantallaCompleta()\">\n        <mat-icon>zoom_out_map</mat-icon>\n    </button>\n    <!-- <button *ngIf=\"config.permiteZoom\" mat-icon-button [matMenuTriggerFor]=\"menu\">\n        <mat-icon>more_vert</mat-icon>\n    </button>\n    <mat-menu #menu=\"matMenu\">\n        <button mat-menu-item (click)=\"onPantallaCompleta()\">\n            <mat-icon>zoom_out_map</mat-icon>\n            <span>Pantalla completa</span>\n        </button>\n    </mat-menu> -->\n</div>\n<div *ngIf=\"config.estaCargando\" class=\"cargando\"></div>\n<div *ngIf=\"datosGrafico.length==0 && config.graficoTipo!='Mapa'\" class=\"sin-datos\" [ngClass]=\"{'con-titulo': config.conTitulo }\">\n    <p>Sin datos</p>\n</div>\n<lib-grafico-barras *ngIf=\"config.graficoTipo=='Barras'\" [ngClass]=\"{'con-titulo': config.conTitulo }\"\n    (seleccion)=\"graficoSeleccion($event)\" [datos]=\"config.datos\" [config]=\"config.graficoConfig\"\n    [datos]=\"datosGrafico\">\n</lib-grafico-barras>\n<lib-grafico-barras-horizontal *ngIf=\"config.graficoTipo=='BarrasHorizontal'\"\n    [ngClass]=\"{'con-titulo': config.conTitulo }\" (seleccion)=\"graficoSeleccion($event)\" [datos]=\"config.datos\"\n    [config]=\"config.graficoConfig\" [datos]=\"datosGrafico\">\n</lib-grafico-barras-horizontal>\n<lib-grafico-heatmap *ngIf=\"config.graficoTipo=='HeatMap'\" [ngClass]=\"{'con-titulo': config.conTitulo }\"\n    (seleccion)=\"graficoSeleccion($event)\" [datos]=\"config.datos\" [config]=\"config.graficoConfig\"\n    [datos]=\"datosGrafico\">\n</lib-grafico-heatmap>\n<lib-grafico-indicador *ngIf=\"config.graficoTipo=='Indicador'\" [ngClass]=\"{'con-titulo': config.conTitulo }\"\n    (seleccion)=\"graficoSeleccion($event)\" [datos]=\"config.datos\" [config]=\"config.graficoConfig\"\n    [datos]=\"datosGrafico\">\n</lib-grafico-indicador>\n<lib-grafico-linea *ngIf=\"config.graficoTipo=='Linea'\" [ngClass]=\"{'con-titulo': config.conTitulo }\"\n    (seleccion)=\"graficoSeleccion($event)\" [datos]=\"config.datos\" [config]=\"config.graficoConfig\"\n    [datos]=\"datosGrafico\">\n</lib-grafico-linea>\n<lib-grafico-mapa *ngIf=\"config.graficoTipo=='Mapa'\" [ngClass]=\"{'con-titulo': config.conTitulo }\"\n    (seleccion)=\"graficoSeleccion($event)\" [datos]=\"config.datos\" [config]=\"config.graficoConfig\"\n    [datos]=\"datosGrafico\">\n</lib-grafico-mapa>\n<lib-grafico-pastel *ngIf=\"config.graficoTipo=='Pastel'\" [ngClass]=\"{'con-titulo': config.conTitulo }\"\n    (seleccion)=\"graficoSeleccion($event)\" [datos]=\"config.datos\" [config]=\"config.graficoConfig\"\n    [datos]=\"datosGrafico\">\n</lib-grafico-pastel>\n<lib-grafico-tabla *ngIf=\"config.graficoTipo=='Tabla'\" [ngClass]=\"{'con-titulo': config.conTitulo }\"\n    (seleccion)=\"graficoSeleccion($event)\" [datos]=\"config.datos\" [config]=\"config.graficoConfig\"\n    [datos]=\"datosGrafico\">\n</lib-grafico-tabla>\n<lib-grafico-treemap *ngIf=\"config.graficoTipo=='TreeMap'\" [ngClass]=\"{'con-titulo': config.conTitulo }\"\n    (seleccion)=\"graficoSeleccion($event)\" [datos]=\"config.datos\" [config]=\"config.graficoConfig\"\n    [datos]=\"datosGrafico\">\n</lib-grafico-treemap>\n<lib-grafico-velocimetro *ngIf=\"config.graficoTipo=='Velocimetro'\" [ngClass]=\"{'con-titulo': config.conTitulo }\"\n    (seleccion)=\"graficoSeleccion($event)\" [datos]=\"config.datos\" [config]=\"config.graficoConfig\"\n    [datos]=\"datosGrafico\">\n</lib-grafico-velocimetro>",
        styles: [":host{background:#fff;overflow:hidden;position:relative}:host>.titulo{align-content:center;align-items:center;display:flex;justify-content:center;padding:2px 2px 2px 12px;border-bottom:1px solid #ccc;min-height:45px}:host>.titulo>div{flex:1 1 auto}:host>:last-child{width:100%;height:100%}:host>:last-child.con-titulo{height:calc(100% - 46px)}@-webkit-keyframes spin{0%{transform:rotate(0)}100%{transform:rotate(360deg)}}@keyframes spin{0%{transform:rotate(0)}100%{transform:rotate(360deg)}}.cargando{position:absolute;top:0;bottom:0;left:0;right:0;background:rgba(255,255,255,.7);z-index:100}.cargando:after{content:\"\";position:absolute;top:50%;left:50%;margin:-20px;border:5px solid #f3f3f3;border-top:5px solid #3498db;border-radius:50%;width:40px;height:40px;-webkit-animation:2s linear infinite spin;animation:2s linear infinite spin}.sin-datos{position:absolute;top:0;bottom:0;left:0;right:0;background:#fff;z-index:100}.sin-datos.con-titulo{top:45px}.sin-datos>p{text-align:center;margin:30px auto;color:#777}"]
    })
], DashboardPanelComponent);

let GraficoBarrasHorizontalComponent = class GraficoBarrasHorizontalComponent {
    constructor(generadorIdService) {
        this.seleccion = new EventEmitter();
        this.idGrafico = generadorIdService.obtenerId('gbh_id_');
    }
    actualizarData() {
        this.chart.data = this.datos;
    }
    actualizarConfiguracion() {
        this.categoryAxis.dataFields.category = this.config.campoCategoria;
        this.series.dataFields.valueX = this.config.campoValor;
        this.series.dataFields.categoryY = this.config.campoCategoria;
    }
    ngOnChanges(changes) {
        if (this.chart) {
            if (changes.datos) {
                this.actualizarData();
            }
            if (changes.config) {
                this.actualizarConfiguracion();
            }
        }
    }
    ngOnInit() { }
    ngAfterViewInit() {
        unuseAllThemes();
        switch (this.config.tipoVisual) {
            case 1:
                useTheme(am4themes_dataviz);
                break;
            case 2:
                useTheme(am4themes_material);
                break;
            case 3:
                useTheme(am4themes_kelly);
                break;
            case 4:
                useTheme(am4themes_frozen);
                break;
            case 5:
                useTheme(am4themes_moonrisekingdom);
                break;
            case 6:
                useTheme(am4themes_spiritedaway);
                break;
        }
        useTheme(am4themes_animated);
        this.chart = create(this.idGrafico, XYChart);
        this.chart.padding(10, 30, 10, 20);
        this.categoryAxis = this.chart.yAxes.push(new CategoryAxis());
        this.categoryAxis.renderer.grid.template.location = 0;
        this.categoryAxis.renderer.minGridDistance = 30;
        this.categoryAxis.renderer.grid.template.disabled = true;
        this.categoryAxis.fontSize = 12;
        this.categoryAxis.renderer.inversed = true;
        const valueAxis = this.chart.xAxes.push(new ValueAxis());
        valueAxis.min = 0;
        this.series = this.chart.series.push(new ColumnSeries());
        this.series.columns.template.tooltipText = '{categoryY}: {valueX.value}';
        this.series.columns.template.strokeOpacity = 0;
        const labelBullet = this.series.bullets.push(new LabelBullet());
        labelBullet.label.horizontalCenter = 'left';
        labelBullet.label.dx = 10;
        labelBullet.label.text = '{valueX.value}';
        labelBullet.locationX = 1;
        this.series.columns.template.adapter.add('fill', (fill, target) => {
            return this.chart.colors.getIndex(target.dataItem.index);
        });
        this.categoryAxis.sortBySeries = this.series;
        // Evento click
        this.series.columns.template.events.on('hit', (event) => {
            this.seleccion.emit(event.target.dataItem.dataContext);
        });
        this.actualizarConfiguracion();
        this.actualizarData();
    }
    ngOnDestroy() {
        this.chart.dispose();
    }
};
GraficoBarrasHorizontalComponent.ctorParameters = () => [
    { type: GeneradorIdService }
];
__decorate([
    Input()
], GraficoBarrasHorizontalComponent.prototype, "config", void 0);
__decorate([
    Input()
], GraficoBarrasHorizontalComponent.prototype, "datos", void 0);
__decorate([
    Output()
], GraficoBarrasHorizontalComponent.prototype, "seleccion", void 0);
GraficoBarrasHorizontalComponent = __decorate([
    Component({
        selector: 'lib-grafico-barras-horizontal',
        template: "<div id=\"{{idGrafico}}\" style=\"width: 100%; height: 100%\"></div>",
        styles: [":host{display:block}"]
    })
], GraficoBarrasHorizontalComponent);

let WmGraficosModule = class WmGraficosModule {
};
WmGraficosModule = __decorate([
    NgModule({
        declarations: [
            GraficoPastelComponent,
            GraficoTablaComponent,
            GraficoMapaComponent,
            GraficoBarrasComponent,
            GraficoIndicadorComponent,
            GraficoHeatmapComponent,
            GraficoTreemapComponent,
            GraficoLineaComponent,
            GraficoVelocimetroComponent,
            DashboardComponent,
            DashboardPanelComponent,
            GraficoBarrasHorizontalComponent,
        ],
        imports: [
            CommonModule,
            MatTableModule,
            MatPaginatorModule,
            MatFormFieldModule,
            MatInputModule,
            MatSortModule,
            MatIconModule,
            MatButtonModule,
            MatBadgeModule,
            MatMenuModule,
            MatChipsModule,
            GoogleMapsModule,
        ],
        exports: [
            GraficoPastelComponent,
            GraficoTablaComponent,
            GraficoMapaComponent,
            GraficoBarrasComponent,
            GraficoIndicadorComponent,
            GraficoHeatmapComponent,
            GraficoTreemapComponent,
            GraficoLineaComponent,
            GraficoVelocimetroComponent,
            DashboardComponent,
            DashboardPanelComponent,
        ],
    })
], WmGraficosModule);

/*
 * Public API Surface of wm-graficos
 */

/**
 * Generated bundle index. Do not edit.
 */

export { WmGraficosModule, GraficoPastelComponent as ɵa, GeneradorIdService as ɵb, GraficoTablaComponent as ɵc, GraficoMapaComponent as ɵd, GraficoBarrasComponent as ɵe, GraficoIndicadorComponent as ɵf, GraficoHeatmapComponent as ɵg, GraficoTreemapComponent as ɵh, GraficoLineaComponent as ɵi, GraficoVelocimetroComponent as ɵj, DashboardComponent as ɵk, ApiService as ɵl, DashboardPanelComponent as ɵm, GraficoBarrasHorizontalComponent as ɵn };
//# sourceMappingURL=wm-graficos.js.map
